bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution.__init__
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaDistribution.__init__